@@ -157,7 +157,7 @@ class Action(Parametrizable, Permittable):
 
     button_color = None
     """
-    The olor to be used on icon-less buttons for this action
+    The color to be used on icon-less buttons for this action
     (i.e. which have no :attr:`icon_name`).  See also
     :attr:`lino.core.site.Site.use_silk_icons`.
 
@@ -1214,7 +1214,8 @@ class WrappedAction(Action):
     callable_from = 'd'
 
     WRAPPED_ATTRS = ('help_text', 'icon_name', 'react_icon_name', 'label',
-                     'sort_index', 'required_roles', 'button_text')
+                     'sort_index', 'required_roles', 'button_text', 'window_type',
+                     'opens_a_window', 'parameters', 'no_params_window')
 
     def __init__(self, bound_action, **kwargs):
         self.bound_action = bound_action
