@@ -1,25 +1,23 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2009-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """Callback handling
 """
 
-from builtins import object
-
 import logging; logger = logging.getLogger(__name__)
 
 import sys
 import os
 from os.path import join, dirname, exists
+from hashlib import md5
 
 # from multiprocessing import Process, Manager
 
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
-from django.utils.encoding import force_text
+from django.utils.translation import gettext_lazy as _
+from django.utils.encoding import force_str
 
 from etgen.html import tostring
-from hashlib import md5
 
 # from lino.core.requests import ActorRequest
 
@@ -38,15 +36,10 @@ class CallbackChoice(object):
 
 
 class Callback(object):
-    """A callback is a question that rose during an AJAX action.
-    The original action is pending until we get a request
+    """A callback is a question that rose during an action.
+    The action's execution is pending until we get a request
     that answers the question.
 
-    TODO: move all callback-related code out of
-    :mod:`lino.core.kernel` into to a separate module and install it
-    as a "kernel plugin" in a similar way as :mod:`lino.core.web` and
-    :mod:`lino.utils.config`.
-
     """
     title = _('Confirmation')
 
@@ -83,7 +76,8 @@ class Callback(object):
 
     def run(self, choice):
         if choice not in self.choices_dict:
-            raise Exception("Can not run choice|%s| not in avaliable choices %s"%(choice,self.choices_dict))
+            raise Exception("Can not run choice|%s| not in available choices %s" % (
+                choice, self.choices_dict))
         self.choices_dict[choice].func(self.ar)
 
 class unused_CallbackManager(object):
@@ -157,7 +151,7 @@ def add_callback(ar, *msgs, uid=None):
 
     """
     if len(msgs) > 1:
-        msg = '\n'.join([force_text(s) for s in msgs])
+        msg = '\n'.join([force_str(s) for s in msgs])
     else:
         msg = msgs[0]
     # logger.info("20160526 add_callback(%s)", msg)
@@ -200,7 +194,7 @@ def popCallBack(resp):
     """
     return {cb:c for cb,c in resp.items() if cb.startswith("xcallback__")}
 
-def applyCallbackChoice(resp = {}, data={}, choice="yes"):
+def applyCallbackChoice(resp={}, data={}, choice="yes"):
     """
     Looks up all other callback IDs from a previous responce as well as adds your new choice to the data for resending.
     Used in testing
@@ -209,6 +203,7 @@ def applyCallbackChoice(resp = {}, data={}, choice="yes"):
     callback = {"xcallback__" + resp["xcallback"]['id'] : choice}
     data.update(callback)
     return data
+
 # mpman = Manager()
 # mgr = CallbackManager()
 #
