@@ -19,6 +19,8 @@ from django.db.models.query import QuerySet
 
 from django.apps import apps ; get_models = apps.get_models
 
+from etgen.html import tostring
+
 from lino.core import fields
 from lino.core import actions
 from lino.core.model import Model
@@ -296,16 +298,18 @@ class Table(AbstractTable):
         # return cls.model._meta.get_field(name)
 
     @classmethod
-    def as_story(cls, obj, ar):
-        if isinstance(ar, ActionRequest):
-            ar = cls.request(master_instance=ar)
-        rows = ar.selected_rows or ar.sliced_data_iterator
+    def get_table_story(cls, obj, ar):
+        sar = cls.request_from(ar, master_instance=obj, is_on_main_actor=False)
         html = ""
-        # meta = []
-        for obj in rows:
-            html += obj.as_summary_row(ar)
-            # meta.append({'id': obj.pk})
-        return html#, meta
+        for obj in sar.data_iterator:
+            html += obj.as_story_item(ar)
+        if cls.insert_action is not None:
+            if not cls.editable:
+                return html
+            ir = cls.insert_action.request_from(sar)
+            if ir.get_permission():
+                html = tostring(ir.ar2button()) + html
+        return html
 
     @classmethod
     def get_pk_field(self):
