@@ -89,6 +89,10 @@ class RichTextField(models.TextField):
         self.textfield_format = fmt
 
 
+class PreviewTextField(RichTextField):
+    pass
+
+
 class PercentageField(models.DecimalField):
 
     """
@@ -405,6 +409,20 @@ class HtmlBox(DisplayField):
     """
     pass
 
+class DelayedHtmlBox(HtmlBox):
+    """
+
+    A simple extention of :class:`HtmlBox` that uses the :class:`DelayedValue
+    <lino.utils.DelayedValue>` for its related store field value.
+
+    """
+
+    # Needed when the object passes through the process of params_values creation, as if this object were a choicelist
+    empty_strings_allowed = True
+
+    def __init__(self, *args, **kwargs):
+        kwargs.update(delayed_value=True)
+        super().__init__(*args, **kwargs)
 
 # class VirtualGetter(object):
 #     """A wrapper object for getting the content of a virtual field
@@ -749,6 +767,9 @@ def htmlbox(*args, **kwargs):
     """
     return virtualfield(HtmlBox(*args, **kwargs))
 
+def delayedhtmlbox(*args, **kwargs):
+    return virtualfield(DelayedHtmlBox(*args, **kwargs))
+
 
 def requestfield(*args, **kw):
     """
@@ -1321,7 +1342,7 @@ def pointer_factory(cls, othermodel, *args, **kw):
 
     - It supports `othermodel` being `None` or the name of some
       non-installed model and returns a :class:`DummyField` in that
-      case.  This difference is useful when designing reusable models.
+      case. This difference is useful when designing reusable models.
 
     - Explicitly sets the default value for `on_delete
       <https://docs.djangoproject.com/en/3.2/ref/models/fields/#django.db.models.ForeignKey.on_delete>`__
@@ -1382,7 +1403,7 @@ def make_remote_field(model, name):
         leaf_chooser = choosers.check_for_chooser(model, fld)
 
         field_chain.append(fld)
-        if isinstance(fld, models.OneToOneRel):
+        if isinstance(fld, (models.OneToOneRel, models.ForeignKey)):
             editable = True
         if getattr(fld, 'remote_field', None):
             model = fld.remote_field.model
@@ -1424,10 +1445,10 @@ def make_remote_field(model, name):
         try:
             for fld in field_chain:
                 # print("20180712a %s" % fld)
-                if isinstance(fld, models.OneToOneRel):
+                if isinstance(fld, (models.OneToOneRel, models.ForeignKey)):
                     reltarget = getattr(target, fld.name, None)
                     if reltarget is None:
-                        rkw = { fld.field.name: target}
+                        rkw = { fld.field.name: target }
                         # print(
                         #     "20180712 create {}({})".format(
                         #         fld.related_model, rkw))
@@ -1450,12 +1471,11 @@ def make_remote_field(model, name):
                     #         target, fld.name, value))
                     return True
         except Exception as e:
-            raise e.__class__(
-                "Error while setting %s: %s" % (name, e))
-            # ~ if False: # only for debugging
-            if True:  # see 20130802
+            if False:  # only for debugging
                 logger.exception(e)
                 return str(e)
+            raise e.__class__(
+                "Error while setting %s: %s" % (name, e))
             return False
 
     rf = RemoteField(getter, name, fld, setter)
