@@ -112,6 +112,7 @@ class Kernel(object):
         # logger.info("20140227 Kernel.__init__() done")
 
     _code_mtime = None
+    _lino_version = None
 
     @property
     def code_mtime(self):
@@ -122,6 +123,34 @@ class Kernel(object):
             self._code_mtime = codetime()
         return self._code_mtime
 
+    @property
+    def lino_version(self):
+        """
+
+        This gathers all of the apps version numbers and add them up in order,
+        to use it as modification stamp. Any updates on any of the dependent
+        django apps will increase this collective version number and will be
+        used as a stamp to propagate changes through the system.
+
+        This is automatically activated when :attr:`Site.never_build_site_cache
+        <lino.core.site.Site.never_build_site_cache>` is set to `True`,
+        supposedly used in a production server.
+
+        """
+        if self._lino_version is None:
+            mods = set([mod.split('.')[0] for mod in settings.INSTALLED_APPS])
+            version = [0, 0, 0]
+            for mod in mods:
+                m = import_module(mod)
+                if hasattr(m, '__version__'):
+                    v = [int(num) for num in m.__version__.split('.')]
+                    for i in range(len(v)):
+                        version[i] += v[i]
+                        if i == 2:
+                            break
+            version = [str(num) for num in version]
+            self._lino_version = '.'.join(version)
+        return self._lino_version
 
     def kernel_startup(self, site):
         """This is a part of a Lino site startup.  The Django Model
@@ -316,8 +345,7 @@ class Kernel(object):
             import_module(site.workflows_module)
 
         for p in site.installed_plugins:
-            if isinstance(p, Plugin):
-                p.before_analyze()
+            p.before_analyze()
 
         # logger.info("20150429 Gonna send pre_analyze signal")
         pre_analyze.send(site, models_list=models_list)
@@ -374,15 +402,8 @@ class Kernel(object):
         #             #     print("20181212", model)
         #             break
 
-        # Install help texts to all database fields:
-        for model in models_list:
-            for f in model._meta.get_fields(include_parents=False):
-            # for f in model._meta.get_fields():
-                site.install_help_text(f, model, f.name)
-            # for f in model._meta.private_fields:
-            #     site.install_help_text(f, model, f.name)
-            # if model.__name__ == "Client":
-            #     print(' '.join([f.name for f in model._meta.private_fields]))
+        for p in site.installed_plugins:
+            p.before_actors_discover()
 
         actors.discover()
 
@@ -395,8 +416,6 @@ class Kernel(object):
             #     logger.error("Failed to initialize actor %s : %s", a, e)
             #     raise # Exception("Failed to class_init {} : {}".format(a, e))
 
-
-
         for a in actors.actors_list:
             a.init_layouts()
 
@@ -493,38 +512,10 @@ class Kernel(object):
         for a in actors.actors_list:
             for i, ea in enumerate(a.collect_extra_actions()):
                 a._bind_action(ea.action_name, ea, False)
-                # ba = actors.resolve_action(ba)
-                # ba = mi.bound_action
-                # a._bind_action(ba.full_name(),
-                #     actions.QuickLinkAction(ba, label=mi.label), False)
-                # print("20210602", new_ba.required)
+            a._actions_list = sorted(a._actions_list, key=lambda ba: ba.action.sort_index)
 
-        for a in actors.actors_list:
-
-            site.install_help_text(a)
-            if a.parameters is not None:
-                for name, fld in a.parameters.items():
-                    site.install_help_text(fld, a, name)
-
-            for ba in a.get_actions():
-                # site.install_help_text(
-                #     ba.action.__class__, ba.action.action_name)
-                # site.install_help_text(ba.action, a, ba.action.action_name)
-                # site.install_help_text(ba.action, ba.action.__class__)
-                if a.model is not None:
-                    site.install_help_text(
-                        ba.action, a.model, ba.action.action_name)
-                site.install_help_text(
-                    ba.action, a, ba.action.action_name)
-                site.install_help_text(ba.action.__class__)
-                # site.install_help_text(
-                #     ba.action, ba.action.__class__,
-                #     attrname=ba.action.action_name)
-
-                if ba.action.parameters is not None:
-                    for name, fld in ba.action.parameters.items():
-                        site.install_help_text(
-                            fld, ba.action.__class__, name)
+        # for p in site.installed_plugins:
+        #     p.after_discover()
 
         self.reserved_names = [getattr(constants, n)
                                for n in constants.URL_PARAMS]
@@ -853,7 +844,7 @@ class Kernel(object):
         # if not exists(settings.STATIC_ROOT):
         #     logger.info("STATIC_ROOT does not exist: %s", settings.STATIC_ROOT)
         #     return 0
-        fn = join(settings.MEDIA_ROOT, fn)
+        fn = join(settings.SITE.site_cache_root, fn)
         # fn = join(settings.STATIC_ROOT, fn)
         # fn = join(self.site.cache_dir, fn)
         if not force and not self._must_build and exists(fn):
