@@ -315,7 +315,17 @@ class LayoutHandle(object):
             name = picture
         elif len(a) == 2:
             name = a[0]
-            a = a[1].split("x", 1)
+            if ':' in a[1]:
+                aas = a[1].split(':')
+                for v in aas:
+                    m = re.match(r'^(\d+)(x(\d+))?$', v)
+                    if m is not None:
+                        a = v
+                        continue
+                    options[v] = True
+            else:
+                a = a[1]
+            a = a.split("x", 1)
             if len(a) == 1:
                 options.update(width=int(a[0]))
             elif len(a) == 2:
@@ -385,7 +395,7 @@ class BaseLayout(object):
     It is designed to be subclassed by applications programmers.
 
 
-    In some cases we still use the (reprecated)  methods
+    In some cases we still use the (deprecated)  methods
     :meth:`set_detail_layout <lino.core.actors.Actor.set_detail_layout>`,
     :meth:`set_insert_layout <lino.core.actors.Actor.set_insert_layout>`,
     :meth:`add_detail_panel <lino.core.actors.Actor.add_detail_panel>`
