@@ -42,7 +42,6 @@ except ImportError:
     bleach = None
 
 
-
 class Model(models.Model, fields.TableRow):
     """
     Lino's extension of the plain Django Model class.
@@ -435,7 +434,9 @@ class Model(models.Model, fields.TableRow):
                     continue
                 try:
                     new = bleach.clean(
-                        old, tags=settings.SITE.bleach_allowed_tags, strip=True)
+                        old, tags=settings.SITE.bleach_allowed_tags,
+                        attributes=settings.SITE.bleach_allowed_attributes,
+                        strip=True)
                 except TypeError as e:
                     logger.warning(
                         "Could not bleach %r : %s (%s)", old, e, self)
@@ -553,6 +554,45 @@ class Model(models.Model, fields.TableRow):
         """
         pass
 
+    def as_search_item(self, ar):
+        def _get_attr(attr):
+            value = getattr(self, attr)
+            if value.startswith('<'):
+                return value
+            return tostring(E.p(value))
+        if hasattr(self, 'body_short_preview'):
+            content = _get_attr('body_short_preview')
+        elif hasattr(self, 'description'):
+            content = _get_attr('description')
+        else:
+            content = ""
+        return tostring(E.h4(ar.obj2html(self))) + ar.parse_memo(content)
+
+    def as_story_item(self, ar):
+        if settings.SITE.is_installed('search') and issubclass(
+            ar.actor, settings.SITE.models.search.SiteSearchBase):
+            return self.as_search_item(ar)
+        return self.as_summary_row(ar)
+
+    @property
+    def edge_ngram_field(self):
+        values = [str(getattr(self, field.name)) for field in self.quick_search_fields + self.quick_search_fields_digit]
+        return ' '.join(values)
+
+    @property
+    def haystack_rendered_field(self):
+        """
+
+        Used by haystack.indexes.SearchIndex.
+
+        Haystack stores the value from this property in the search engine
+        backend along with the document so that there's no need to make a
+        database query and show this value as the search result.
+
+        """
+        ar = self.__class__.get_default_table().request()
+        return self.as_search_item(ar)
+
     def as_summary_row(self, ar):
         # used by tickets.Tickets table in the bootstrap frontend
         # also when display_mode = constants.DISPLAY_MODE_STORY it returns html
@@ -948,6 +988,10 @@ LINO_MODEL_ATTRIBS = (
     'get_default_table',
     'get_default_table',
     'get_layout_aliases',
+    'edge_ngram_field',
+    'as_search_item',
+    'as_story_item',
+    'haystack_rendered_field',
     'as_summary_row',
     'summary_row_template',
     'get_related_project',
