@@ -19,6 +19,7 @@ from os.path import exists, join, dirname, isdir, abspath
 from six.moves.urllib.parse import urlencode
 import inspect
 
+from .features import FEATURES_HOOKS#, LINO_FEATURES
 
 class Plugin(object):
     """The base class for all plugin descriptors.
@@ -498,3 +499,19 @@ class Plugin(object):
         parts.append(str(pk))
         parts += args
         return self.build_plain_url(*parts, **kw)
+
+    @classmethod
+    def setup_site_features(cls, feats):
+        """
+        arguments:
+            feats: The instance of :class:`lino.core.features.Features`. Also
+            accessible through :class:`Plugin` attribute :attr:`Plugin.feature`.
+        """
+        pass
+
+if not hasattr(Plugin, 'features'):
+    for name, value in FEATURES_HOOKS.items():
+        if callable(value):
+            setattr(Plugin, name, classmethod(value))
+        else:
+            setattr(Plugin, name, value)
