@@ -398,6 +398,28 @@ class OneToOneStoreField(RelatedMixin, StoreField):
         return v.obj2href(ar)
 
 
+class PreviewTextStoreField(StoreField):
+    list_values_count = 3
+
+    def column_names(self):
+        # yield self.options['name']
+        # yield self.options['name'] + constants.CHOICES_HIDDEN_SUFFIX
+        yield self.name
+        yield self.name + "_short_preview"
+        yield self.name + "_full_preview"
+
+    def value2list(self, ar, v, l, row):
+        if isinstance(row, PhantomRow):
+            l.append(None)
+        else:
+            l.append(getattr(row, self.name))
+
+    def value2dict(self, ar, k, v, d, row):
+        if not isinstance(row, PhantomRow):
+            d[self.name] = getattr(row, self.name)
+            d[self.name+ "_short_preview"] = getattr(row, self.name+ "_short_preview")
+            d[self.name+ "_full_preview"] = getattr(row, self.name+ "_full_preview")
+
 
 # class LinkedForeignKeyField(ForeignKeyStoreField):
 
@@ -1005,6 +1027,8 @@ def create_atomizer(holder, fld, name):
         return DisplayStoreField(fld, name)
     if isinstance(fld, models.IntegerField):
         return IntegerStoreField(fld, name)
+    if isinstance(fld, fields.PreviewTextField):
+        return PreviewTextStoreField(fld, name)
     if isinstance(fld, models.ManyToOneRel):
         # raise Exception("20190625 {} {} {}".format(holder, fld, name))
         return
@@ -1049,7 +1073,10 @@ class ParameterStore(BaseStore):
         # debug = False
         for fld in self.param_fields:
             #     debug = True
-            v = pv.get(fld.name, None)
+            if fld.delayed_value and len(ar.selected_rows) == 1:
+                v = DelayedValue(ar, fld.name, ar.selected_rows[0])
+            else:
+                v = pv.get(fld.name, None)
             # if "__" in fld.name:
             #     print("20200430", fld, v)
             fld.value2dict(ar, fld.name, v, d, None)
