@@ -29,6 +29,23 @@ from .fields import RemoteField, FakeField, TableRow
 
 from .requests import ActionRequest
 
+class SearchQuerySet:
+    pass
+class SearchQuery:
+    pass
+
+if settings.SITE.is_installed('search'):
+    if settings.SITE.use_elasticsearch:
+        try:
+            from elasticsearch_django.models import SearchQuery
+        except ImportError:
+            pass
+    elif settings.SITE.use_solr:
+        try:
+            from haystack.query import SearchQuerySet
+        except ImportError:
+            pass
+
 WARNINGS_LOGGED = dict()
 
 
@@ -45,14 +62,14 @@ def sliced_data_iterator(qs, offset, limit):
     # qs is either a Django QuerySet or iterable
     # When limit is None or 0, offset cannot be -1
     if offset is not None:
+        if isinstance(qs, QuerySet):
+            num = qs.count()
+        else:
+            num = len(qs)
         if offset == -1:
-            if isinstance(qs, QuerySet):
-                num = qs.count()
-            else:
-                num = len(qs)
             page_num = num // limit
             offset = limit * page_num
-        qs = qs[offset:]
+        qs = qs[offset:num]
     if limit is not None and limit != 0:
         qs = qs[:limit]
     return qs
@@ -146,8 +163,15 @@ class TableRequest(ActionRequest):
         if isinstance(self._data_iterator, GeneratorType):
             # print 20150718, self._data_iterator
             self._data_iterator = tuple(self._data_iterator)
-        self._sliced_data_iterator = sliced_data_iterator(
-            self._data_iterator, self.offset, self.limit)
+        if isinstance(self._data_iterator, (SearchQuery, SearchQuerySet)):
+            self._sliced_data_iterator = tuple(
+                self.actor.get_rows_from_search_query(
+                    self._data_iterator, self
+                )
+            )
+        else:
+            self._sliced_data_iterator = sliced_data_iterator(
+                self._data_iterator, self.offset, self.limit)
         # logger.info("20171116 executed : %s", self._sliced_data_iterator)
 
     def must_execute(self):
@@ -185,6 +209,8 @@ class TableRequest(ActionRequest):
         See `/blog/2012/0124`
         """
         di = self.data_iterator
+        if isinstance(di, SearchQuery):
+            return di.total_hits
         if isinstance(di, QuerySet):
             return di.count()
             # try:
