@@ -14,6 +14,7 @@ from django.urls import re_path as url
 from django.conf.urls import include
 from django.conf.urls.static import static
 from lino.core.utils import is_devserver
+from lino.core.site import has_socialauth
 
 # we must explicitly call django.setup() because when running under
 # mod_wsgi this is not done automatically as with runserver (or at
@@ -41,7 +42,7 @@ for p in site.installed_plugins:
     else:
         urlpatterns.append(url(prx, include(pat)))
 
-if site.social_auth_backends:
+if has_socialauth and site.social_auth_backends:
     urlpatterns.append(
         url('^oauth/', include('social_django.urls', namespace='social')))
 
