@@ -1,5 +1,5 @@
 # Copyright 2015-2018 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
 Defines a set of user types "Anonymous", "User" and
@@ -9,7 +9,7 @@ This can be used directly as :attr:`user_types_module
 <lino.core.site.Site.user_types_module>` for simple applications.
 """
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from lino.core.roles import UserRole, SiteAdmin, SiteUser
 # from lino.modlib.office.roles import OfficeUser, OfficeStaff
 from lino.modlib.users.choicelists import UserTypes
