@@ -63,7 +63,7 @@ class Phonable(model.Model):
 
     url = models.URLField(_('URL'), blank=True)
     phone = models.CharField(_('Phone'), max_length=200, blank=True)
-    gsm = models.CharField(_('GSM'), max_length=200, blank=True)
+    gsm = models.CharField(_('Mobile'), max_length=200, blank=True)
     fax = models.CharField(_('Fax'), max_length=200, blank=True)
 
 
