@@ -1,4 +1,4 @@
-# Copyright 2012-2020 Rumma & Ko Ltd
+# Copyright 2012-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import re
@@ -13,15 +13,17 @@ from django.conf import settings
 
 from lino.utils.report import EmptyTable
 from lino.core.utils import get_models
+from lino.core import constants
 
 from lino.utils.code import codetime
 from lino.utils.diag import analyzer
 from etgen.html import E
 
 from lino.api import rt, dd
-from .roles import SiteSearcher
+
 from .choicelists import TimeZones, DateFormats
 
+
 def dtfmt(dt):
     if isinstance(dt, float):
         # assert dt
@@ -32,99 +34,6 @@ def dtfmt(dt):
         time=settings.SITE.strftime(dt.time()))
 
 
-
-class SiteSearch(dd.VirtualTable):
-    required_roles = dd.login_required(SiteSearcher)
-    label = _("Search")
-    column_names = "description matches"
-    private_apps = frozenset(['sessions', 'contenttypes', 'users'])
-
-
-    # _site_search_tables = []
-    # @classmethod
-    # def register(cls, t):
-    #     assert t not in cls._site_search_tables
-    #     cls._site_search_tables.append(t)
-
-    # disabled_models = set()
-    # @classmethod
-    # def disable_model(cls, m):
-    #     cls.disabled_models.add(m)
-
-    @classmethod
-    def get_data_rows(cls, ar):
-        if ar.quick_search is None or len(ar.quick_search) < 2:
-            return
-
-        user_type = ar.get_user().user_type
-        # for model in rt.models_by_base(Searchable):
-        for model in get_models():
-            if model._meta.app_label in cls.private_apps:
-                continue
-            if model.show_in_site_search:
-                t = model.get_default_table()
-                # for t in cls._site_search_tables:
-                if not t.get_view_permission(user_type):
-                    continue
-                sar = t.request(
-                    parent=ar, quick_search=ar.quick_search)
-                for obj in sar:
-                    if obj.show_in_site_search:  # don't show calview.HeaderRow
-                        yield obj
-
-    @dd.displayfield(_("Description"))
-    def description(self, obj, ar):
-        elems = []
-        elems.append(ar.obj2html(obj))
-        # elems.append(u" ({})".format(obj._meta.verbose_name))
-        elems += (" (", str(obj._meta.verbose_name), ")")
-        return E.p(*elems)
-
-    @dd.displayfield(_("Matches"))
-    def matches(self, obj, ar):
-        # if not obj.__class__.show_in_site_search:
-        #     return ""
-        def bold(mo):
-            return "<b>{}</b>".format(mo.group(0))
-        matches = {}
-        for w in ar.quick_search.split():
-            char_search = True
-            lst = None
-            if w.startswith("#") and w[1:].isdigit():
-                w = w[1:]
-                char_search = False
-            if w.isdigit():
-                i = int(w)
-                for de in obj.quick_search_fields_digit:
-                    if de.value_from_object(obj) == i:
-                    # if getattr(obj, fn) == int(w):
-                        matches.setdefault(de, w)
-            if char_search:
-                for de in obj.quick_search_fields:
-                    s = matches.get(de, None)
-                    if s is None:
-                        s = str(de.value_from_object(obj))
-                        s = escape(s, quote=False)
-                    r, count = re.subn(w, bold, s, flags=re.IGNORECASE)
-                    if count:
-                        matches[de] = r
-
-        chunks = []
-        for de in obj.quick_search_fields + obj.quick_search_fields_digit:
-            lst = matches.get(de, None)
-            if lst:
-                chunks.append(de.name + ":" + lst)
-        from lxml import etree
-        s = ', '.join(chunks)
-        s = "<span>" + s + "</span>"
-        try:
-            return etree.fromstring(s)
-        except Exception as e:
-            raise Exception("{} : {}".format(e, s))
-        # return etree.fromstring(', '.join(chunks))
-        # return E.raw(', '.join(chunks))
-
-
 class About(EmptyTable):
     """
     Display information about this web site.  This defines the window
@@ -163,6 +72,24 @@ class About(EmptyTable):
                 dd.fdf(settings.SITE.the_demo_date))
             body.append(E.p(s))
 
+        feats = settings.SITE.features.features
+        body.append(E.h4(str(_("Available Features:"))))
+        style = "border: 1px solid black; border-radius: 2px; padding: 5px;"
+
+        f_table_head = []
+        f_table_head.append(E.th(str(_("Feature")), style=style))
+        f_table_head.append(E.th(str(_("Description")), style=style))
+        f_table_head.append(E.th(str(_("Status")), style=style))
+        thead = E.thead(E.tr(*f_table_head))
+        trs = []
+
+        for key in feats:
+            row = E.tr(E.td(key, style=style), E.td(str(feats[key]['description']), style=style),
+            E.td(str(_("Active")) if key in settings.SITE.features.active_features else str(_("Inactive")), style=style))
+            trs.append(row)
+        tbody = E.tbody(*trs)
+        body.append(E.table(thead, tbody))
+
         body.append(E.p(str(_("Source timestamps:"))))
         items = []
         times = []
