@@ -15,6 +15,7 @@ from lino.mixins import CreatedModified, BabelNamed
 from lino.mixins.periods import DateRangeObservable
 from lino.modlib.users.mixins import UserAuthored
 from lino.modlib.notify.mixins import ChangeNotifier
+from lino.modlib.search.mixins import ElasticSearchable
 from lino.modlib.gfks.mixins import Controllable
 from lino.modlib.memo.mixins import Previewable
 from lino.modlib.publisher.mixins import Publishable
@@ -35,7 +36,7 @@ class CommentType(BabelNamed):
 
 
 
-class Comment(CreatedModified, UserAuthored, Controllable,
+class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
               ChangeNotifier, Previewable, Publishable, DateRangeObservable):
     class Meta(object):
         app_label = 'comments'
@@ -43,6 +44,75 @@ class Comment(CreatedModified, UserAuthored, Controllable,
         verbose_name = _("Comment")
         verbose_name_plural = _("Comments")
 
+    ES_indexes = [(
+        'comment',
+        {
+            "mappings": {
+                "properties": {
+                    "body": {
+                        "type": "text",
+                        "fields": {
+                            "keyword": {
+                                "type": "keyword",
+                                "ignore_above": 256
+                            }
+                        },
+                        "analyzer": "autocomplete",
+                        "search_analyzer": "autocomplete_search"
+                    },
+                    "body_full_preview": {
+                        "type": "text",
+                        "fields": {
+                            "keyword": {
+                                "type": "keyword",
+                                "ignore_above": 256
+                            }
+                        },
+                        "analyzer": "autocomplete",
+                        "search_analyzer": "autocomplete_search"
+                    },
+                    "body_short_preview": {
+                        "type": "text",
+                        "fields": {
+                            "keyword": {
+                                "type": "keyword",
+                                "ignore_above": 256
+                            }
+                        },
+                        "analyzer": "autocomplete",
+                        "search_analyzer": "autocomplete_search"
+                    },
+                    "model": {
+                        "type": "text",
+                        "fields": {
+                            "keyword": {
+                                "type": "keyword",
+                                "ignore_above": 256
+                            }
+                        },
+                        "analyzer": "autocomplete",
+                        "search_analyzer": "autocomplete_search"
+                    },
+                    "modified": {
+                        "type": "date"
+                    },
+                    "owner_id": {
+                        "type": "long"
+                    },
+                    "owner_type": {
+                        "type": "long"
+                    },
+                    "private": {
+                        "type": "boolean"
+                    },
+                    "user": {
+                        "type": "long"
+                    }
+                }
+            }
+        }
+    )]
+
     publisher_location = "c"
 
     reply_to = dd.ForeignKey(
