@@ -1,12 +1,13 @@
-# Copyright 2015-2019 Rumma & Ko Ltd
+# Copyright 2015-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 """User roles for this plugin.
 
 """
 
 from lino.core.roles import UserRole
+from lino.modlib.search.roles import SiteSearcher
 
-class CommentsReader(UserRole):
+class CommentsReader(SiteSearcher):
     """
     Can read all comments. If the aplication defines AnonymousUser
     having this role, then all (non-private) comments are publicly
