@@ -48,14 +48,14 @@ class CommentDetail(dd.DetailLayout):
     general1 = """
     owner private
     reply_to pick_my_emotion
-    body_full_preview
+    body #body_full_preview
     """
     # general2 = """
     # RepliesByComment
     # """
 
     more = dd.Panel("""
-    body more2
+    #body more2
     """, label=_("More"))
 
     more2 = """
@@ -455,7 +455,7 @@ class RepliesByComment(CommentsByX):
     master_key = 'reply_to'
     # display_mode = "list"
     stay_in_grid = True
-    display_mode = DISPLAY_MODE_STORY
+    # display_mode = DISPLAY_MODE_STORY
     # title = _("Replies")
     label = _("Replies")
     simple_slavegrid_header = True
