@@ -26,7 +26,7 @@ from lino.core.gfks import ContentType
 
 from lino.core.actions import (ShowEmptyTable, ShowDetail,
                                ShowInsert, ShowTable, SubmitDetail,
-                               SubmitInsert)
+                               SubmitInsert, WrappedAction)
 from lino.core import dbtables
 from lino.core import kernel
 from lino.core import tables
@@ -158,13 +158,6 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             return dict(text=prepare_label(v), href=url)
         return v
 
-    def get_action_params(self, ar, ba, obj, **kw):
-        if ba.action.parameters:
-            fv = ba.action.params_layout.params_store.pv2list(
-                ar, ar.action_param_values)
-            kw[constants.URL_PARAM_FIELD_VALUES] = fv
-        return kw
-
     def action_button(self, obj, ar, ba, label=None, **kw):
         label = label or ba.get_button_label()
         if len(label) == 1:
@@ -299,11 +292,19 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         return "%s()" % self.get_panel_btn_handler(bound_action)
 
     def get_panel_btn_handler(self, ba):
+        if isinstance(ba.action, WrappedAction):
+            original_ba = ba.action.bound_action
+            if original_ba.action.parameters and not original_ba.action.no_params_window:
+                return "Lino.param_action_handler(Lino.%s)" % original_ba.full_name()
+            return "Lino.wrapped_action_handler('Lino.%s')" % ba.action.action_name
         if not ba.action.action_name:
             raise Exception(
                 "Cannot make handler for nameless action %r" % ba.action)
         if ba.action.js_handler:
-            h = ba.action.js_handler % ba.action.__dict__
+            if callable(ba.action.js_handler):
+                h = ba.action.js_handler(ba.actor)
+            else:
+                h = ba.action.js_handler % ba.action.__dict__
         else:
             if ba.action.select_rows:
                 h = 'Lino.row_action_handler('
@@ -408,7 +409,8 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
                 user = request.subst_user
 
         def getit():
-            if not settings.SITE.build_js_cache_on_startup:
+            if (not settings.SITE.build_js_cache_on_startup
+                and not settings.SITE.never_build_site_cache):
                 self.build_js_cache(False)
 
             # Render template
@@ -531,7 +533,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             yield "Lino.main_menu = Lino.main_menu.concat(['->',%s]);" % py2js(login_menu)
 
         else:
-            ba = rt.models.users.UsersOverview.get_action_by_name('sign_in')
+            ba = rt.models.about.About.get_action_by_name('sign_in')
             js = self.action_call(None, ba, {})
             js = "function(){%s}" % js
             login_buttons = [ dict(
@@ -717,7 +719,10 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             window_actions = [ba.action for ba in rpt.get_actions() if
                               ba.action.opens_a_window]
             for ba in rpt.get_actions():
-                if ba.action.parameters and not ba.action.no_params_window:
+                if isinstance(ba.action, WrappedAction):
+                    for ln in self.js_render_wrapped_action(rh, ba):
+                        f.write(ln + '\n')
+                elif ba.action.parameters and not ba.action.no_params_window:
                     pass
                 elif ba.action.opens_a_window:
                     if isinstance(ba.action, (ShowDetail,
@@ -795,18 +800,21 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
 
     def a2btn(self, ba, **kw):
         a = ba.action
-        if a.parameters and not a.no_params_window:
+        selector = a
+        # if isinstance(a, WrappedAction):
+        #     selector = a.bound_action.action
+        if selector.parameters and not selector.no_params_window:
             kw.update(panel_btn_handler=js_code(
                 "Lino.param_action_handler(Lino.%s)" % ba.full_name()))
-        elif isinstance(a, SubmitInsert):
+        elif isinstance(selector, SubmitInsert):
             js = 'function(panel){panel.save()}'
             kw.update(panel_btn_handler=js_code(js))
-        elif isinstance(a, SubmitDetail):
+        elif isinstance(selector, SubmitDetail):
             js = 'function(panel){panel.save()}'
             kw.update(panel_btn_handler=js_code(js))
-        elif isinstance(a, ShowDetail):
+        elif isinstance(selector, ShowDetail):
             kw.update(panel_btn_handler=js_code('Lino.show_detail'))
-        elif isinstance(a, ShowInsert):
+        elif isinstance(selector, ShowInsert):
             kw.update(panel_btn_handler=js_code('Lino.show_insert'))
         else:
             kw.update(
@@ -818,7 +826,6 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             txt = a.button_text or a.get_label()
             if len(txt) == 1:
                 txt = ONE_CHAR_LABEL.format(txt)
-
             kw.update(text=txt)
         kw.update(
             #~ name=a.name,
@@ -828,8 +835,6 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             itemId=a.action_name,
             #~ text=unicode(a.label),
         )
-        if a.key:
-            kw.update(keycode=a.key.keycode)
 
         if a.help_text:
             # if a.__class__.__name__ in ('ChangePassword', 'SubmitDetail'):
@@ -1016,8 +1021,15 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
 
         yield "  layout: 'fit',"
         yield "  auto_save: true,"
-        hotkeys = tbl.get_actions_hotkeys()
-        if hotkeys:
+        hotkeys = []
+        for ba in tbl._actions_list:
+            if ba.action.hotkey and ba.action.hotkey.key:
+                hotkey = vars(ba.action.hotkey)
+                if not hasattr(hotkey, 'ba'):
+                    hotkey['ba'] = ba.action.action_name
+                if hotkey not in hotkeys:
+                    hotkeys.append(hotkey)
+        if len(hotkeys):
             yield "  actions_hotkeys: %s," % py2js(self.actions_hotkeys2js(hotkeys))
         if dh.layout.window_size and dh.layout.window_size[1] == 'auto':
             yield "  autoHeight: true,"
@@ -1235,17 +1247,37 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         yield "});"
         yield ""
 
-    def js_render_custom_action(self, rh, action):
+    def js_render_wrapped_action(self, rh, ba):
+        original_ba = ba.action.bound_action
+        yield "Lino.%s = function(panel, btn, step) {" % ba.action.action_name
+        if isinstance(original_ba.action, ShowDetail):
+            yield "\tvar pk = panel.get_current_record().id;"
+            yield "\tif (pk === -99998) pk = 0;"
+            yield "\tLino.%s.run(null, {record_id: pk});" % original_ba.full_name()
+        elif isinstance(original_ba.action, (ShowTable, ShowEmptyTable, ShowInsert)):
+            yield "\tLino.%s.run(null);" % original_ba.full_name()
+        else:
+            if original_ba.action.select_rows:
+                h = "\tLino.row_action_handler(%s, %s, %s)(panel, btn, step);"
+            else:
+                h = "\tLino.list_action_handler(%s," % py2js(
+                    original_ba.actor.actor_url()) + " %s, %s, %s)(panel, btn, step);"
+            yield h % (py2js(original_ba.action.action_name),
+                py2js(original_ba.action.http_method),
+                original_ba.action.preprocessor)
+        yield "};"
+
+    def js_render_custom_action(self, rh, ba):
         """Defines the non-window action handler used by
         :meth:`row_action_button`
         """
-        yield "Lino.%s = function(rp, is_main, pk, params) { " % action.full_name()
+        yield "Lino.%s = function(rp, is_main, pk, params) { " % ba.full_name()
         yield "  var h = function() { "
         uri = rh.actor.actor_url()
         yield "    Lino.run_row_action(rp, is_main, %s, %s, pk, %s, params, %s);" % (
-            py2js(uri), py2js(action.action.http_method),
-            py2js(action.action.action_name),
-            action.action.preprocessor)
+            py2js(uri), py2js(ba.action.http_method),
+            py2js(ba.action.action_name),
+            ba.action.preprocessor)
         yield "  };"
         yield "  var panel = Ext.getCmp(rp);"
         yield "  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();"
@@ -1363,7 +1395,10 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             yield "LANGUAGE_CHOICES = %s;" % py2js(
                 list(settings.SITE.LANGUAGE_CHOICES))
             yield "MEDIA_URL = %s;" % py2js(settings.SITE.build_media_url())
-            yield "GEN_TIMESTAMP = %s;" % py2js(rt.settings.SITE.kernel.code_mtime)
+            if settings.SITE.never_build_site_cache:
+                yield "GEN_TIMESTAMP = '%s';" % settings.SITE.kernel.lino_version
+            else:
+                yield "GEN_TIMESTAMP = %s;" % py2js(settings.SITE.kernel.code_mtime)
 
         return '\n'.join(fn())
 
