@@ -1,5 +1,5 @@
 # Copyright 2008-2015 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
 Import filters
@@ -7,7 +7,7 @@ Import filters
 
 from lino import ad
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class Plugin(ad.Plugin):
