@@ -3,6 +3,7 @@
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from bs4 import BeautifulSoup
+from bs4.element import Tag
 from lxml import html as lxml_html
 from etgen.html import E, tostring
 import lxml
@@ -12,7 +13,7 @@ from django.utils import translation
 
 from lino.core.model import Model
 from lino.core.requests import BaseRequest
-from lino.core.fields import fields_list, RichTextField
+from lino.core.fields import fields_list, RichTextField, PreviewTextField
 from lino.utils.restify import restify
 from lino.utils.mldbc.fields import BabelTextField
 from lino.core.exceptions import ChangedAPI
@@ -22,6 +23,7 @@ from lino.api import _
 
 def truncate_comment(html_str, max_p_len=300):
     html_str = html_str.strip()  # remove leading or trailing newlines
+
     if not html_str.startswith('<'):
         if len(html_str) > max_p_len:
             txt = html_str[:max_p_len] + "..."
@@ -31,12 +33,28 @@ def truncate_comment(html_str, max_p_len=300):
     soup = BeautifulSoup(html_str, "html.parser")
     ps = soup.find_all(["p", "h1", "h2", "h3", "h4", "h5", "h6", "h7", "h8", "h9", "pre"])
     if len(ps) > 0:
+        anchor_end = '</a>'
         txt = ""
         for p in ps:
-            text = p.text
-            # TODO: something like for w in p.text.split() but using regex
+            text = ""
+            for c in p.contents:
+                if isinstance(c, Tag):
+                    if c.name == 'a':
+                        text += str(c)
+                        max_p_len = max_p_len + len(text) - len(c.text)
+                    else:
+                        text += c.text
+                else:
+                    text += str(c)
+
             if len(txt) + len(text) > max_p_len:
                 txt += text
+                if anchor_end in txt:
+                     ae_index = txt.index(anchor_end) + len(anchor_end)
+                     if ae_index >= max_p_len:
+                         txt = txt[:ae_index]
+                         txt += "..."
+                         break
                 txt = txt[:max_p_len]
                 txt += "..."
                 break
@@ -123,7 +141,7 @@ class Previewable(BasePreviewable):
 
     previewable_field = 'body'
 
-    body = RichTextField(_("Body"), blank=True, format='html', bleached=True)
+    body = PreviewTextField(_("Body"), blank=True, format='html', bleached=True)
     body_short_preview = RichTextField(_("Preview"), blank=True, editable=False)
     body_full_preview = RichTextField(_("Preview (full)"), blank=True, editable=False)
 
