@@ -19,6 +19,7 @@ import logging ; logger = logging.getLogger(__name__)
 import re
 import inspect
 
+from bs4 import BeautifulSoup
 from etgen import etree
 
 COMMAND_REGEX = re.compile(r"\[(\w+)\s*((?:[^[\]]|\[.*?\])*?)\]")
@@ -293,6 +294,30 @@ All remaining arguments are used as the text of the link.
         # logger.debug(msg)
         return msg
 
+    def parse_suggestions(self, src):
+        soup = BeautifulSoup(src, 'html.parser')
+        while True:
+            mention = soup.find('span', attrs={'class': 'mention'})
+            if mention is None:
+                break
+            attrs = mention.attrs
+            link = attrs['data-link']
+            title = attrs['data-title']
+            value = mention.text
+            sanitized_mention = BeautifulSoup(
+                f'<a href="{link}" title="{title}">{value}</a>', 'html.parser')
+            soup.find('span', attrs={'class': "mention"}).replaceWith(sanitized_mention)
+        return str(soup)
+
+    def simplify_suggestions(self, src):
+        soup = BeautifulSoup(src, 'html.parser')
+        while True:
+            mention = soup.find('span', attrs={'class': 'mention'})
+            if mention is None:
+                break
+            soup.find('span', attrs={'class': 'mention'}).replaceWith(BeautifulSoup(mention.text, 'html.parser'))
+        return str(soup)
+
     def parse(self, src, ar=None, context=None):
         """
         Parse the given string `src`, replacing memo commands by their
@@ -307,6 +332,7 @@ All remaining arguments are used as the text of the link.
         """
         usages = dict()
         if self.suggesters:
+            src = self.simplify_suggestions(src)
             regex = self.compile_suggester_regex()
             mf = self.suggester_match_func(ar)
             src = regex.sub(mf, src)
