@@ -35,7 +35,7 @@ class Plugin(ad.Plugin):
     vapid_public_key = "BCPMIR93gv_Di_AHL4i-zew3hB9I5ebPXihpKX44dgsxYxVymMZ79EK4_LIO7fN6d_UwUbz611Uiz7amJN1q2Wg"
     vapid_admin_email = "sharifmehedi24@gmail.com"
 
-    remove_after = 24
+    remove_after = 2*7  # two weeks
     keep_unseen = True
     mark_seen_when_sent = False
 
