@@ -53,5 +53,6 @@ class Plugin(ad.Plugin):
             # 'EXCEPTION_HANDLER': 'lino_noi.lib.rest.utils.exception_handler',
             'UNAUTHENTICATED_USER': 'lino.core.auth.utils.AnonymousUser'
         })
-            
-            
+
+    def get_requirements(self, site):
+        yield 'djangorestframework'
