@@ -38,6 +38,12 @@ class Plugin(ad.Plugin):
     # partner_model = 'contacts.Person'
     partner_model = 'contacts.Partner'
 
+    @classmethod
+    def setup_site_features(self, feats):
+        feats.define_feature(
+            'third_party_authentication',
+            _("Whether to allow login using credentials from third party"))
+
     def on_site_startup(self, site):
         super(Plugin, self).on_site_startup(site)
         # if isinstance(self.partner_model, str):
@@ -63,7 +69,9 @@ class Plugin(ad.Plugin):
     def on_init(self):
         super(Plugin, self).on_init()
         self.site.set_user_model('users.User')
-
+        from lino.core.site import has_socialauth
+        if self.has_feature('third_party_authentication') and has_socialauth:
+            self.needs_plugins.append('social_django')
 
     def setup_config_menu(self, site, user_type, m):
         g = site.plugins.system
@@ -76,7 +84,7 @@ class Plugin(ad.Plugin):
         m.add_action('users.Authorities')
         m.add_action('users.UserTypes')
         m.add_action('users.UserRoles')
-        if site.social_auth_backends is not None:
+        if site.has_feature('third_party_authentication'):
             m.add_action('users.SocialAuths')
 
     def setup_site_menu(self, site, user_type, m):
