@@ -263,7 +263,7 @@ def validate_sessions_limit(request):
             _("There are more than {} active user sessions. Please try again later.").format(
                 dd.plugins.users.active_sessions_limit))
 
-def get_social_auth_links_func(content_header):
+def get_social_auth_links_func(content_header, flex_row):
     def text_fn(*args):
         elems = [E.div(
             E.hr(style="width: -moz-available; margin-right: 1ch;"),
@@ -273,10 +273,13 @@ def get_social_auth_links_func(content_header):
         elems.append(E.br())
         links = []
         for name, href in settings.SITE.get_social_auth_links(chunks=True):
-            links.append(E.span(
-                E.a(E.span(" " + name, CLASS='pi pi-' + name) , href=href),
-                style="padding: 1ch; margin: 2px; border: 2px solid gray; border-radius: 6px;"
-            ))
+            anchor = E.a(E.span(" " + name, CLASS='pi pi-' + name) , href=href)
+            style = "padding: 1ch; margin: 2px; border: 2px solid gray; border-radius: 6px;"
+            if flex_row:
+                el = E.div(anchor, style=style)
+            else:
+                el = E.span(anchor, style=style)
+            links.append(el)
         elems.append(E.div(*links, style="text-align: center;"))
         return tostring(E.div(*elems))
     return text_fn
@@ -288,16 +291,18 @@ class SignIn(dd.Action):
         username=dd.CharField(_("Username")),
         password=dd.PasswordField(_("Password"), blank=True),
         social_auth_links=dd.Constant(
-            get_social_auth_links_func(gettext("Sign in with")))
+            get_social_auth_links_func(gettext("Or sign in with"), flex_row=True))
     )
-    if not settings.SITE.social_auth_backends:
+    if not settings.SITE.has_feature('third_party_authentication'):
         parameters['social_auth_links'] = dd.DummyField()
 
     params_layout = dd.Panel("""
+    login_panel:50 social_auth_links:50
+    """, #label_align=layouts.LABEL_ALIGN_LEFT, window_size=(50, 9),
+    login_panel="""
     username
     password
-    social_auth_links
-    """, label_align=layouts.LABEL_ALIGN_LEFT)
+    """)
 
     http_method = "POST"
     # show_in_bbar = False
@@ -329,9 +334,9 @@ class CreateAccount(dd.Action):
         email=dd.CharField(_("Email")),
         password=dd.PasswordField(_("Password"), blank=True),
         social_auth_links=dd.Constant(
-            get_social_auth_links_func(gettext("Create account with")))
+            get_social_auth_links_func(gettext("Create account with"), flex_row=False))
     )
-    if not settings.SITE.social_auth_backends:
+    if not settings.SITE.has_feature('third_party_authentication'):
         parameters['social_auth_links'] = dd.DummyField()
 
     params_layout = """
@@ -357,6 +362,7 @@ class CreateAccount(dd.Action):
 
         UserTypes = rt.models.users.UserTypes
         ut = UserTypes.get_by_name(dd.plugins.users.user_type_new)
+        pv.pop('social_auth_links')
         obj = User.objects.create_user(user_type=ut, **pv)
         obj.on_create(ar)
         obj.full_clean()
