@@ -171,15 +171,11 @@ class AuthoritiesTaken(Authorities):
     column_names = 'user'
     auto_fit_column_widths = True
 
-if settings.SITE.social_auth_backends:
+from lino.core.site import has_socialauth
+
+if has_socialauth and settings.SITE.has_feature('third_party_authentication'):
+    import social_django
 
-    try:
-        import social_django
-    except ImportError:
-        raise Exception(
-            "Sites with social_auth_backends must also install PSA "
-            "into their environment. Run `pm install` or "
-            "`pip install social-auth-app-django`")
 
     class SocialAuths(dd.Table):
         label = _("Third-party authorizations")
