@@ -226,7 +226,7 @@ class UserPlan(UserAuthored):
     class Meta:
         abstract = True
 
-    today = models.DateField(_("Today"), default=dd.today)
+    today = models.DateField(_("Today"), default=dd.today, editable=False)
 
     update_plan = UpdatePlan()
     start_plan = StartPlan()
