@@ -125,4 +125,4 @@ def configure(globals_dict, django_settings_module=None, project=None):
     interproject.configure(globals_dict, **im)
 
     extlinks = globals_dict['extlinks']
-    extlinks['ticket'] = ('https://jane.mylino.net/#/api/tickets/AllTickets/%s', '#')
+    extlinks['ticket'] = ('https://jane.mylino.net/#/api/tickets/PublicTickets/%s', '#')
