@@ -1,4 +1,4 @@
-# Copyright 2009-2020 Rumma & Ko Ltd
+# Copyright 2009-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Extends the possibilities for defining choices for fields of a
@@ -10,19 +10,7 @@ Django model.
   to store manually entered values
 - :ref:`learning_combos`
 
-Example values:
-
->>> import json
->>> s = '<a href="javascript:Lino.pcsw.Clients.detail.run(\
-null,{ &quot;record_id&quot;: 116 })">BASTIAENSEN Laurent (116)</a>'
->>> print(json.dumps(GFK_HACK.match(s).groups()))
-["pcsw.Clients", "116"]
-
->>> s = '<a href="javascript:Lino.cal.Guests.detail.run(\
-null,{ &quot;record_id&quot;: 6 })">Gast #6 ("Termin #51")</a>'
->>> print(json.dumps(GFK_HACK.match(s).groups()))
-["cal.Guests", "6"]
-
+Example values in :doc:`/topics/utils`.
 
 """
 
