@@ -1,44 +1,11 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2012-2014 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
-"""Example usage:
+"""
+Generating Estonian names.
 
-Some fictive Estonians (each couple one male & one female):
-
->>> for i in range(5):
-...    he = (MALE_FIRST_NAMES_ESTONIA.pop(), LAST_NAMES_ESTONIA.pop())
-...    she = (FEMALE_FIRST_NAMES_ESTONIA.pop(), LAST_NAMES_ESTONIA.pop())
-...    print("%s %s & %s %s" % (he + she))
-Aadu Ivanov & Adeele Tamm
-Aare Saar & Age Sepp
-Aarne Mägi & Age-Kaie Smirnov
-Aaro Vasiliev & Aili Petrov
-Aaron Kask & Aili Kukk
-
->>> streets = Cycler(streets_of_tallinn())
->>> print(len(streets))
-1523
->>> for i in range(5):
-...     print("%s (%s)" % streets.pop())
-Aarde tn (Põhja-Tallinn)
-Aasa tn (Kesklinn)
-Aate tn (Nõmme)
-Abaja põik (Pirita)
-Abaja tn (Pirita)
-
-
-Sources:
-
-- Estonian last names were originally extracted from
-  `www.ekspress.ee <http://www.ekspress.ee/news/paevauudised/eestiuudised/top-500-eesti-koige-levinumad-perekonnanimed.d?id=27677149>`_
-  (I manually added some less frequent names).
-
-- Estonian first names are extracted from my personal database.
-
-- Streets of Tallinn are originally from `www.eki.ee
-  <http://www.eki.ee/knab/tallinn1.htm>`_ (Peter Päll confirmed
-  permission to use it here on 2014-11-07).
+Examples in :doc:`/topics/utils`.
 
 """
 
