@@ -1,8 +1,12 @@
-# Copyright 2009-2020 Rumma & Ko Ltd
+# Copyright 2009-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
-A collection of tools around :doc:`multi-table inheritance </dev/mti>`.
+A collection of tools around multi-table inheritance.
+
+See :doc:`/dev/mti`.
+
+See also :class:`lino.mixins.polymorphic`.
 
 """
 import logging ; logger = logging.getLogger(__name__)
