@@ -154,6 +154,8 @@ class EmptyTable(Frame):
 
     @classmethod
     def wildcard_data_elems(self):
+        if self.parameters is None:
+            return []
         return self.parameters.values()
 
     @classmethod
@@ -161,9 +163,10 @@ class EmptyTable(Frame):
         de = super(EmptyTable, self).get_data_elem(name)
         if de is not None:
             return de
-        de = self.parameters.get(name, None)
-        if de is not None:
-            return de
+        if self.parameters is not None:
+            de = self.parameters.get(name, None)
+            if de is not None:
+                return de
         a = name.split('.')
         if len(a) == 2:
             return getattr(getattr(settings.SITE.models, a[0]), a[1])
