@@ -31,7 +31,7 @@ def min_indent(s):
 
 def doc2rst(s):
     if s is None:
-        return u''
+        return ''
     s = s.expandtabs()
     # If all lines begin with the same indentation, then strip it.
     mi = min_indent(s)
@@ -395,7 +395,7 @@ A list:
   - item 1
   - item 2
   - item 3
-  
+
 A table:
 
   =========== ===========================
