@@ -1,15 +1,13 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2013-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
-"""Defines the :class:`DocTest` and :class:`DemoTestCase` classes.
+"""Defines some TestCase classes that are meant for writing general Python test
+cases (not Django test cases, which are defined in
+:mod:`lino.utils.djangotest`).
 
 """
 
-# import sys
-# import codecs
-# sys.stdout = codecs.getwriter('utf8')(sys.stdout)
-
 import logging ; logger = logging.getLogger(__name__)
 
 import os
@@ -18,6 +16,9 @@ import unittest
 import doctest
 
 from lino.utils.pythontest import TestCase as PythonTestCase
+from lino.utils.instantiator import create_row
+from lino.utils import AttrDict
+from lino.core import constants
 
 import collections
 HttpQuery = collections.namedtuple(
@@ -26,7 +27,11 @@ HttpQuery = collections.namedtuple(
 
 
 class CommonTestCase(unittest.TestCase):
-    """An extended `django.test.TestCase`.
+    """
+
+    A :class:`unittest.TestCase` (not a :class:`django.test.TestCase`) that
+    starts a Django test client on a demo database populated using
+    :manage:`prep`.
 
     """
 
@@ -34,14 +39,11 @@ class CommonTestCase(unittest.TestCase):
         """Create the given database object, run :meth:`full_clean` and
         :meth:`save`, return the object.
 
-        Deprecated. Use :func:`lino.utils.instantiator.create_row`
-        instead.
+        This is here for backwards compatibility.
+        New code should use :func:`lino.utils.instantiator.create_row` instead.
 
         """
-        obj = model(**values)
-        obj.full_clean()
-        obj.save()
-        return obj
+        return create_row(model, **values)
 
     def check_json_result(self, response, expected_keys=None, msg=''):
         """Checks the result of response which is expected to return a
@@ -63,8 +65,6 @@ class CommonTestCase(unittest.TestCase):
             self.assertEqual(set(result.keys()), set(expected_keys.split()))
         return result
 
-
-
     def assertEquivalent(self, a, b, report_plain=False):
         """Compares two strings `a` (expected) and `b` (got), ignoring
         whitespace repetitions and writing a logger message in case
@@ -144,13 +144,15 @@ class DocTest(unittest.TestCase):
 
 
 class DemoTestCase(PythonTestCase, CommonTestCase):
-    """Used to define tests that are to be run directly in the demo
-    database, *without* using the Django test runner (i.e. without
-    creating a temporary test database).
+    """
 
-    It expects the demo database to be initialized, and it works only in
-    an environment with :attr:`lino.core.site.Site.remote_user_header`
-    set to ``'REMOTE_USER'``.
+    Base class for unit tests that are meant to run directly in a demo
+    project that has been initialized with :manage:`prep`.
+
+    It expects the demo database to be initialized, and it should be read-only,
+    i.e. not modify any data.
+
+    This is used by the :manage:`demotest` command.
 
     """
     def __call__(self, *args, **kw):
@@ -158,6 +160,27 @@ class DemoTestCase(PythonTestCase, CommonTestCase):
         self.client = Client()
         return super(DemoTestCase, self).__call__(*args, **kw)
 
+    def login(self, username, pwd):
+        """
+
+        Invoke the :class:`lino.modlib.users.SignIn` action for the given
+        username and password. Unlike :meth:`django.test.Client.force_login`,
+        this simulates a real login, which later causes Lino to build the JS
+        cache for this user.
+
+        """
+
+        data = {
+            constants.URL_PARAM_FIELD_VALUES: [username, pwd],
+            constants.URL_PARAM_ACTION_NAME: 'sign_in'}
+        url = "/api/about/About/-99998"
+        res = self.client.post(url, data)
+        self.assertEqual(res.status_code, 200)
+        content = res.content.decode()
+        d = json.loads(content)
+        # return str(d.keys())
+        return AttrDict(d)
+
     def demo_get(self, username, url_base, json_fields, expected_rows,
                  **kwargs):
         from django.conf import settings
@@ -165,17 +188,13 @@ class DemoTestCase(PythonTestCase, CommonTestCase):
                          expected_rows, kwargs)
         url = settings.SITE.buildurl(case.url_base, **case.kwargs)
 
-        if True:
-            msg = 'Using remote authentication, but no user credentials found.'
-            try:
-                response = self.client.get(url)
-                self.fail("Expected '%s'" % msg)
-                #~ raise Exception("Expected '%s'" % msg)
-            except Exception:
-                pass
-                #~ self.tc.assertEqual(str(e),msg)
-                #~ if str(e) != msg:
-                        #~ raise Exception("Expected %r but got %r" % (msg,str(e)))
+        msg = 'Using remote authentication, but no user credentials found.'
+        try:
+            response = self.client.get(url)
+            self.fail("Expected '%s'" % msg)
+            #~ raise Exception("Expected '%s'" % msg)
+        except Exception:
+            pass
 
         response = self.client.get(url, REMOTE_USER='foo')
         self.assertEqual(
@@ -184,78 +203,19 @@ class DemoTestCase(PythonTestCase, CommonTestCase):
                 response.status_code, url))
 
         response = self.client.get(url, REMOTE_USER=case.username)
-        # try:
-        if True:
-            user = settings.SITE.user_model.objects.get(
-                username=case.username)
-            result = self.check_json_result(
-                response, case.json_fields,
-                "GET %s for user %s" % (url, user))
+        user = settings.SITE.user_model.objects.get(
+            username=case.username)
+        result = self.check_json_result(
+            response, case.json_fields,
+            "GET %s for user %s" % (url, user))
 
-            num = case.expected_rows
-            if num is not None:
-                if not isinstance(num, tuple):
-                    num = [num]
-                if result['count'] not in num:
-                    msg = "%s got %s rows instead of %s" % (
-                        url, result['count'], num)
-                    #~ raise Exception("[%d] %s" % (i, msg))
-                    self.fail(msg)
-                    #~ failures += 1
-
-        # except Exception as e:
-        #     print("%s:\n%s" % (url, e))
-        #     raise
-
-
-
-#class WebIndexTestCase(DjangoManageTestCase):
-#class WebIndexTestCase(RemoteAuthTestCase):
-class WebIndexTestCase(DemoTestCase):
-    """
-
-    Test whether a :manage:`runserver` on this database would respond with 200
-    to an anonymous request.
-
-    You add this to your test suite by just importing it. No subclassing needed.
-
-    By convention this is done in a file :xfile:`test_webindex.py`, i.e. when
-    such a file is present in the :xfile:`tests` directory of a demo project,
-    this test is being run as part of :manage:`test`.
-
-    """
-    # 20200513 : WebIndexTestCase now runs on the populatd demo data, not as an empty django test case
-
-    # removed 20150819 because it took unbearably much time for
-    # welfare test suite:
-    # override_djangosite_settings = dict(
-    #     build_js_cache_on_startup=True)
-
-    tested_urls = ('/', '/?su=3', '/?su=1234')
-
-    def test_get_index(self):
-        from django.conf import settings
-        # client = Client()
-        for url in self.tested_urls:
-            # print("20200513", url)
-            res = self.client.get(url)
-            self.assertEqual(
-                res.status_code, 200,
-                "Status code %s other than 200 for anonymous on GET %s" % (
-                    res.status_code, url))
-
-        if settings.SITE.user_model:
-            for user in settings.SITE.user_model.objects.all():
-                if user.user_type:
-                    self.client.force_login(user)
-                    res = self.client.get(url)
-                    self.assertEqual(
-                        res.status_code, 200,
-                        "Status code {} for {} on GET {}".format(
-                            res.status_code, user, url))
-
-        # res = client.get(url, REMOTE_USER='robin')
-        # self.assertEqual(
-        #     res.status_code, 200,
-        #     "Status code %s other than 200 for robin on GET %s" % (
-        #         res.status_code, url))
+        num = case.expected_rows
+        if num is not None:
+            if not isinstance(num, tuple):
+                num = [num]
+            if result['count'] not in num:
+                msg = "%s got %s rows instead of %s" % (
+                    url, result['count'], num)
+                #~ raise Exception("[%d] %s" % (i, msg))
+                self.fail(msg)
+                #~ failures += 1
